/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

%{C++
#define NSILOCALE_COLLATE "NSILOCALE_COLLATE"
#define NSILOCALE_CTYPE  "NSILOCALE_CTYPE"
#define NSILOCALE_MONETARY "NSILOCALE_MONETARY"
#define NSILOCALE_NUMERIC "NSILOCALE_NUMERIC"
#define NSILOCALE_TIME "NSILOCALE_TIME"
#define NSILOCALE_MESSAGE "NSILOCALE_MESSAGES"

#define NS_LOCALE_CONTRACTID "@mozilla.org/intl/nslocale;1"
%}

/**
 * Represents one locale, which can be used for things like sorting text strings
 * and formatting numbers, dates and times.
 */
[scriptable, uuid(21035ee0-4556-11d3-91cd-00105aa3f7dc)]
interface nsILocale : nsISupports
{
    /**
     * Get the locale code for a given category.
     *
     * A locale code is of the form language[-COUNTRY[-region]], where
     * "language" is an ISO 639 language code (two letter codes preferred over
     * three letter codes when available), "COUNTRY" is an ISO 3166 two letter
     * country code, and "region" is a string of up to 5 letters.
     *
     * A category is one of the following:
     * NSILOCALE_CTYPE: Character classification and case conversion.
     * NSILOCALE_COLLATE: Collation order. How strings are sorted.
     * NSILOCALE_MONETARY: Monetary formatting.
     * NSILOCALE_NUMERIC: Numeric, non-monetary formatting.
     * NSILOCALE_TIME: Date and time formats.
     * NSILOCALE_MESSAGES: Related to fonts, character encodings etc.
     * 
     * @param category
     *        The category of interest.
     * @return The locale code to be used for the given category.
     */
    AString getCategory(in AString category);
};
